@@ -2,8 +2,8 @@ from __future__ import annotations
 
 import argparse
 
+import pwndbg.aglib.kernel
 import pwndbg.commands
-import pwndbg.gdblib.kernel
 from pwndbg.commands import CommandCategory
 
 parser = argparse.ArgumentParser(description="Return the kernel commandline (/proc/cmdline).")
@@ -14,4 +14,4 @@ parser = argparse.ArgumentParser(description="Return the kernel commandline (/pr
 @pwndbg.commands.OnlyWithKernelDebugSyms
 @pwndbg.commands.OnlyWhenPagingEnabled
 def kcmdline() -> None:
-    print(pwndbg.gdblib.kernel.kcmdline())
+    print(pwndbg.aglib.kernel.kcmdline())
