@@ -2,8 +2,8 @@ from __future__ import annotations
 
 import argparse
 
+import pwndbg.aglib.kernel
 import pwndbg.commands
-import pwndbg.gdblib.kernel
 from pwndbg.commands import CommandCategory
 
 parser = argparse.ArgumentParser(description="Outputs the kernel version (/proc/version).")
@@ -13,4 +13,4 @@ parser = argparse.ArgumentParser(description="Outputs the kernel version (/proc/
 @pwndbg.commands.OnlyWhenQemuKernel
 @pwndbg.commands.OnlyWhenPagingEnabled
 def kversion() -> None:
-    print(pwndbg.gdblib.kernel.kversion())
+    print(pwndbg.aglib.kernel.kversion())
