@@ -4,16 +4,17 @@ import argparse
 
 import gdb
 
+import pwndbg.aglib.memory
+import pwndbg.aglib.proc
 import pwndbg.auxv
 import pwndbg.commands
 import pwndbg.commands.context
 import pwndbg.commands.telescope
-import pwndbg.gdblib.proc
 from pwndbg.color import message
 from pwndbg.commands import CommandCategory
 
 
-@pwndbg.commands.ArgparsedCommand("Gets the current file.")
+@pwndbg.commands.ArgparsedCommand("Gets the current file.", category=CommandCategory.MISC)
 @pwndbg.commands.OnlyWhenRunning
 def getfile() -> None:
     print(repr(pwndbg.auxv.get().AT_EXECFN))
@@ -28,7 +29,7 @@ def xuntil(target) -> None:
     try:
         addr = target
 
-        if not pwndbg.gdblib.memory.peek(addr):
+        if not pwndbg.aglib.memory.peek(addr):
             print(message.error("Invalid address %#x" % addr))
             return
 
@@ -43,11 +44,7 @@ def xuntil(target) -> None:
         spec = target
 
     gdb.Breakpoint(spec, temporary=True)
-    if pwndbg.gdblib.proc.alive:
+    if pwndbg.aglib.proc.alive:
         gdb.execute("continue", from_tty=False)
     else:
         gdb.execute("run", from_tty=False)
-
-
-xinfo = pwndbg.commands.context.context
-xprint = pwndbg.commands.telescope.telescope
