@@ -7,33 +7,35 @@ import os
 import struct
 from typing import Set
 
-import gdb
 import pwnlib
 
 import pwndbg
+import pwndbg.aglib.arch
+import pwndbg.aglib.disasm
+import pwndbg.aglib.vmmap
 import pwndbg.color.memory as M
 import pwndbg.commands
 import pwndbg.enhance
-import pwndbg.gdblib.arch
-import pwndbg.gdblib.disasm
-import pwndbg.gdblib.vmmap
 import pwndbg.search
 from pwndbg.color import message
 from pwndbg.commands import CommandCategory
 
+if pwndbg.dbg.is_gdblib_available():
+    import gdb
+
 saved: Set[int] = set()
 
 
-def print_search_hit(address) -> None:
+def print_search_hit(address: int) -> None:
     """Prints out a single search hit.
 
     Arguments:
-        address(int): Address to print
+        address: Address to print
     """
     if not address:
         return
 
-    vmmap = pwndbg.gdblib.vmmap.find(address)
+    vmmap = pwndbg.aglib.vmmap.find(address)
     if vmmap:
         region = os.path.basename(vmmap.objfile)
     else:
@@ -204,9 +206,12 @@ def search(
     if not arch:
         arch = pwnlib.context.context.arch
 
+    # Initialize is_pointer to track whether the search type is a pointer
+    is_pointer = None
     # Adjust pointer sizes to the local architecture
     if type == "pointer":
-        type = {4: "dword", 8: "qword"}[pwndbg.gdblib.arch.ptrsize]
+        type = {4: "dword", 8: "qword"}[pwndbg.aglib.arch.ptrsize]
+        is_pointer = True
 
     if save is None:
         save = bool(pwndbg.config.auto_save_search)
@@ -229,8 +234,8 @@ def search(
     # Convert to an integer if needed, and pack to bytes
     if type not in ("string", "bytes", "asm"):
         value = pwndbg.commands.fix_int(value)
-        value &= pwndbg.gdblib.arch.ptrmask
-        fmt = {"little": "<", "big": ">"}[pwndbg.gdblib.arch.endian] + {
+        value &= pwndbg.aglib.arch.ptrmask
+        fmt = {"little": "<", "big": ">"}[pwndbg.aglib.arch.endian] + {
             "byte": "B",
             "short": "H",
             "word": "H",
@@ -253,8 +258,28 @@ def search(
         bits_for_arch = pwnlib.context.context.architectures.get(arch, {}).get("bits")
         value = pwnlib.asm.asm(value, arch=arch, bits=bits_for_arch)
 
+    # `pwndbg.search.search` expects a `bytes` object for its pattern. Convert the string pattern we
+    # were given to a bytes object by encoding it as an UTF-8 byte sequence. This matches the behavior
+    # we previously got by calling `gdb.Inferior.search_memory` with an `str`, since right about GDB
+    # version 7.x or 8.x[1], as it uses a `Py_buffer` object populated with an `'s*'` pattern, which
+    # has been encoding `str` object as a UTF-8 byte sequence since Python 3.1[2].
+    #
+    # [1]: https://sourceware.org/git/?p=binutils-gdb.git;a=blame;f=gdb/python/py-inferior.c;h=a1042ee72ac733091f7572bc04b072546d3c1519;hb=23c84db5b3cb4e8a0d555c76e1a0ab56dc8355f3
+    # [2]: https://docs.python.org/3.1/c-api/arg.html#strings-and-buffers
+
+    elif type == "bytes" and not hex:
+        try:
+            value = value.encode("utf-8")
+        except UnicodeError as what:
+            print(
+                message.error(
+                    f"Invalid pattern '{value}'. Patterns of type `bytes` must be encodable in UTF-8: {what}"
+                )
+            )
+            return
+
     # Find the mappings that we're looking for
-    mappings = pwndbg.gdblib.vmmap.get()
+    mappings = pwndbg.aglib.vmmap.get()
 
     if mapping_name:
         mappings = [m for m in mappings if mapping_name in m.objfile]
@@ -263,11 +288,22 @@ def search(
         print(message.error("Could not find mapping %r" % mapping_name))
         return
 
+    # Output appropriate messages based on the detected search type for better clarity
+    if is_pointer:
+        print("Searching for a pointer-width integer: " + repr(value))
+    elif type == "word" or type == "short":
+        print("Searching for a 2-byte integer: " + repr(value))
+    elif type == "dword":
+        print("Searching for a 4-byte integer: " + repr(value))
+    elif type == "qword":
+        print("Searching for an 8-byte integer: " + repr(value))
+    elif type == "string":
+        print("Searching for string: " + repr(value))
     # If next is passed, only perform a manual search over previously saved addresses
-    if type == "asm" or asmbp:
+    elif type == "asm" or asmbp:
         print("Searching for instruction (assembled value): " + repr(value))
     else:
-        print("Searching for value: " + repr(value))
+        print("Searching for byte: " + repr(value))
 
     if next:
         val_len = len(value)
@@ -276,7 +312,7 @@ def search(
         i = 0
         for addr in saved:
             try:
-                val = pwndbg.gdblib.memory.read(addr, val_len)
+                val = pwndbg.aglib.memory.read(addr, val_len)
             except Exception:
                 continue
             if val == value:
@@ -307,8 +343,13 @@ def search(
         if save:
             saved.add(address)
         if asmbp:
-            # set breakpoint on the instruction
-            gdb.Breakpoint("*%#x" % address, temporary=False)
+            if pwndbg.dbg.is_gdblib_available():
+                # set breakpoint on the instruction
+                gdb.Breakpoint("*%#x" % address, temporary=False)
+            else:
+                print(
+                    f"breakpoints are not supported outside of GDB yet, would be set at {address:#x}"
+                )
 
         if not trunc_out or i < 20:
             print_search_hit(address)
