@@ -16,6 +16,7 @@ import pwndbg.color.context as C
 import pwndbg.color.memory as M
 import pwndbg.color.message
 import pwndbg.commands
+from pwndbg.commands import CommandCategory
 from pwndbg.lib.regs import aarch64
 from pwndbg.lib.regs import amd64
 from pwndbg.lib.regs import arm
@@ -64,7 +65,7 @@ parser.add_argument(
 )
 
 
-@pwndbg.commands.ArgparsedCommand(parser)
+@pwndbg.commands.ArgparsedCommand(parser, CommandCategory.MISC)
 @pwndbg.commands.OnlyWhenRunning
 @pwndbg.aglib.proc.OnlyWithArch(["x86-64", "i386", "aarch64", "arm"])
 def sigreturn(address: int = None, display_all=False, print_address=False) -> None:
