@@ -13,26 +13,30 @@ from typing import NamedTuple
 from typing import Tuple
 
 import capstone as C
-import gdb
 import unicorn as U
 import unicorn.riscv_const
 
+import pwndbg.aglib.arch
+import pwndbg.aglib.disasm
+import pwndbg.aglib.memory
+import pwndbg.aglib.regs
+import pwndbg.aglib.strings
+import pwndbg.aglib.symbol
+import pwndbg.aglib.vmmap
 import pwndbg.chain
 import pwndbg.color.enhance as E
 import pwndbg.color.memory as M
+import pwndbg.dbg
 import pwndbg.enhance
-import pwndbg.gdblib.arch
-import pwndbg.gdblib.disasm
-import pwndbg.gdblib.memory
-import pwndbg.gdblib.regs
-import pwndbg.gdblib.strings
-import pwndbg.gdblib.symbol
-import pwndbg.gdblib.vmmap
 import pwndbg.integration
+import pwndbg.lib.memory
 import pwndbg.lib.regs
 from pwndbg import color
 from pwndbg.color.syntax_highlight import syntax_highlight
 
+if pwndbg.dbg.is_gdblib_available():
+    import gdb
+
 
 def parse_consts(u_consts) -> Dict[str, int]:
     """
@@ -186,6 +190,7 @@ BANNED_INSTRUCTIONS = {
     "mips": {C.mips.MIPS_INS_RDHWR},
     "arm": ARM_BANNED_INSTRUCTIONS,
     "armcm": ARM_BANNED_INSTRUCTIONS,
+    "aarch64": {C.arm64.ARM64_INS_MRS},
 }
 
 # https://github.com/unicorn-engine/unicorn/issues/550
@@ -206,7 +211,7 @@ class InstructionExecutedResult(NamedTuple):
 # with a copy of the current processor state.
 class Emulator:
     def __init__(self) -> None:
-        self.arch = pwndbg.gdblib.arch.current
+        self.arch = pwndbg.aglib.arch.name
 
         if self.arch not in arch_to_UC:
             raise NotImplementedError(f"Cannot emulate code for {self.arch}")
@@ -219,7 +224,7 @@ class Emulator:
         debug(DEBUG_INIT, "uc = U.Uc(%r, %r)", (arch_to_UC[self.arch], self.uc_mode))
         self.uc = U.Uc(arch_to_UC[self.arch], self.uc_mode)
 
-        self.regs: pwndbg.lib.regs.RegisterSet = pwndbg.gdblib.regs.current
+        self.regs: pwndbg.lib.regs.RegisterSet = pwndbg.aglib.regs.current
 
         # Whether the emulator is allowed to emulate instructions
         # There are cases when the emulator is incorrect or we want to disable it for certain instruction types,
@@ -248,7 +253,7 @@ class Emulator:
             if reg in blacklisted_regs:
                 debug(DEBUG_INIT, "Skipping blacklisted register %r", reg)
                 continue
-            value = getattr(pwndbg.gdblib.regs, reg)
+            value = getattr(pwndbg.aglib.regs, reg)
             if None in (enum, value):
                 if reg not in blacklisted_regs:
                     debug(DEBUG_INIT, "# Could not set register %r", reg)
@@ -269,7 +274,7 @@ class Emulator:
         self.hook_add(U.UC_HOOK_INTR, self.hook_intr)
 
         # Map in the page that $pc is on
-        self.map_page(pwndbg.gdblib.regs.pc)
+        self.map_page(pwndbg.aglib.regs.pc)
 
         # Instruction tracing
         if DEBUG & DEBUG_TRACE:
@@ -291,7 +296,7 @@ class Emulator:
     # Read size worth of memory, return None on error
     def read_memory(self, address: int, size: int) -> bytes | None:
         # Don't attempt if the address is not mapped on the host process
-        if not pwndbg.gdblib.vmmap.find(address):
+        if not pwndbg.aglib.vmmap.find(address):
             return None
 
         value = None
@@ -331,7 +336,7 @@ class Emulator:
     # read_size typically must be either 1, 2, 4, or 8. It dictates the size to read
     # Naturally, if it is less than the pointer size, then only one value would be telescoped
     def telescope(self, address: int, limit: int, read_size: int = None) -> List[int]:
-        read_size = read_size if read_size is not None else pwndbg.gdblib.arch.ptrsize
+        read_size = read_size if read_size is not None else pwndbg.aglib.arch.ptrsize
 
         result = [address]
 
@@ -345,9 +350,9 @@ class Emulator:
 
             value = self.read_memory(address, read_size)
             if value is not None:
-                # address = pwndbg.gdblib.arch.unpack(value)
-                address = pwndbg.gdblib.arch.unpack_size(value, read_size)
-                address &= pwndbg.gdblib.arch.ptrmask
+                # address = pwndbg.aglib.arch.unpack(value)
+                address = pwndbg.aglib.arch.unpack_size(value, read_size)
+                address &= pwndbg.aglib.arch.ptrmask
                 result.append(address)
             else:
                 break
@@ -371,7 +376,7 @@ class Emulator:
         # Colorize the chain
         rest = []
         for link in chain:
-            symbol = pwndbg.gdblib.symbol.get(link) or None
+            symbol = pwndbg.aglib.symbol.resolve_addr(link) or None
             if symbol:
                 symbol = f"{link:#x} ({symbol})"
             rest.append(M.get(link, symbol))
@@ -405,9 +410,9 @@ class Emulator:
         # Near identical to pwndbg.enhance.enhance, just read from emulator memory
 
         # Determine if its on a page - we do this in the real processes memory
-        page = pwndbg.gdblib.vmmap.find(value)
+        page = pwndbg.aglib.vmmap.find(value)
         can_read = True
-        if not page or None is pwndbg.gdblib.memory.peek(value):
+        if not page or None is pwndbg.aglib.memory.peek(value):
             can_read = False
 
         if not can_read:
@@ -427,13 +432,13 @@ class Emulator:
             rwx = exe = False
 
         if exe:
-            pwndbg_instr = pwndbg.gdblib.disasm.one_raw(value)
+            pwndbg_instr = pwndbg.aglib.disasm.one_raw(value)
             if pwndbg_instr:
                 instr = f"{pwndbg_instr.mnemonic} {pwndbg_instr.op_str}"
                 if pwndbg.config.syntax_highlight:
                     instr = syntax_highlight(instr)
 
-        # szval = pwndbg.gdblib.strings.get(value) or None
+        # szval = pwndbg.aglib.strings.get(value) or None
         # Read from emulator memory
         szval = self.memory_read_string(value, max_string_len=enhance_string_len, max_read=None)
         szval0 = szval
@@ -441,15 +446,15 @@ class Emulator:
             szval = E.string(repr(szval))
 
         # Fix for case when we can't read the end address anyway (#946)
-        if value + pwndbg.gdblib.arch.ptrsize > page.end:
+        if value + pwndbg.aglib.arch.ptrsize > page.end:
             return E.integer(pwndbg.enhance.int_str(value))
 
         # Read from emulator memory
-        # intval = int(pwndbg.gdblib.memory.get_typed_pointer_value(pwndbg.gdblib.typeinfo.pvoid, value))
-        read_value = self.read_memory(value, pwndbg.gdblib.arch.ptrsize)
+        # intval = int(pwndbg.aglib.memory.get_typed_pointer_value(pwndbg.aglib.typeinfo.pvoid, value))
+        read_value = self.read_memory(value, pwndbg.aglib.arch.ptrsize)
         if read_value is not None:
-            # intval = pwndbg.gdblib.arch.unpack(read_value)
-            intval = pwndbg.gdblib.arch.unpack_size(read_value, pwndbg.gdblib.arch.ptrsize)
+            # intval = pwndbg.aglib.arch.unpack(read_value)
+            intval = pwndbg.aglib.arch.unpack_size(read_value, pwndbg.aglib.arch.ptrsize)
         else:
             # This occurs when Unicorn fails to read the memory - which it shouldn't, as the
             # read_memory call will map the pages necessary, and this function assumes
@@ -460,7 +465,7 @@ class Emulator:
         if 0 <= intval < 10:
             intval = E.integer(str(intval))
         else:
-            intval = E.integer("%#x" % int(intval & pwndbg.gdblib.arch.ptrmask))
+            intval = E.integer("%#x" % int(intval & pwndbg.aglib.arch.ptrmask))
 
         retval = []
 
@@ -485,7 +490,7 @@ class Emulator:
 
         # Otherwise strings have preference
         elif szval:
-            if len(szval0) < pwndbg.gdblib.arch.ptrsize:
+            if len(szval0) < pwndbg.aglib.arch.ptrsize:
                 retval = [intval, szval]
             else:
                 retval = [szval]
@@ -507,10 +512,10 @@ class Emulator:
     # Return None if cannot find str
     def memory_read_string(self, address: int, max_string_len=None, max_read=None) -> str | None:
         if max_string_len is None:
-            max_string_len = pwndbg.gdblib.strings.length
+            max_string_len = pwndbg.aglib.strings.length
 
         if max_read is None:
-            max_read = pwndbg.gdblib.strings.length
+            max_read = pwndbg.aglib.strings.length
 
         # Read string
         sz = self.read_memory(address, max_read)
@@ -542,7 +547,7 @@ class Emulator:
 
     def update_pc(self, pc=None) -> None:
         if pc is None:
-            pc = pwndbg.gdblib.regs.pc
+            pc = pwndbg.aglib.regs.pc
         self.uc.reg_write(self.get_reg_enum(self.regs.pc), pc)
 
     def read_thumb_bit(self) -> int:
@@ -554,7 +559,7 @@ class Emulator:
 
         Return None if the Thumb bit is not relevent to the current architecture
 
-        Mimics the `read_thumb_bit` function defined in gdblib/arch.py
+        Mimics the `read_thumb_bit` function defined in aglib/arch.py
         """
         if self.arch == "arm":
             if (cpsr := self.cpsr) is not None:
@@ -568,26 +573,29 @@ class Emulator:
         """
         Retrieve the mode used by Unicorn for the current architecture.
         """
-        arch = pwndbg.gdblib.arch.current
+        arch = pwndbg.aglib.arch.name
         mode = 0
 
         if arch == "armcm":
             mode |= (
                 (U.UC_MODE_MCLASS | U.UC_MODE_THUMB)
-                if (pwndbg.gdblib.regs.xpsr & (1 << 24))
+                if (pwndbg.aglib.regs.xpsr & (1 << 24))
                 else U.UC_MODE_MCLASS
             )
 
         elif arch in ("arm", "aarch64"):
-            mode |= U.UC_MODE_THUMB if (pwndbg.gdblib.regs.cpsr & (1 << 5)) else U.UC_MODE_ARM
+            mode |= U.UC_MODE_THUMB if (pwndbg.aglib.regs.cpsr & (1 << 5)) else U.UC_MODE_ARM
 
-        elif arch == "mips" and "isa32r6" in gdb.newest_frame().architecture().name():
+        elif (
+            arch == "mips"
+            and pwndbg.dbg.is_gdblib_available()
+            and "isa32r6" in gdb.newest_frame().architecture().name()
+        ):
             mode |= U.UC_MODE_MIPS32R6
-
         else:
-            mode |= {4: U.UC_MODE_32, 8: U.UC_MODE_64}[pwndbg.gdblib.arch.ptrsize]
+            mode |= {4: U.UC_MODE_32, 8: U.UC_MODE_64}[pwndbg.aglib.arch.ptrsize]
 
-        if pwndbg.gdblib.arch.endian == "little":
+        if pwndbg.aglib.arch.endian == "little":
             mode |= U.UC_MODE_LITTLE_ENDIAN
         else:
             mode |= U.UC_MODE_BIG_ENDIAN
@@ -601,9 +609,9 @@ class Emulator:
         debug(DEBUG_MEM_MAP, "# Mapping %#x-%#x", (page, page + size))
 
         try:
-            data = pwndbg.gdblib.memory.read(page, size)
+            data = pwndbg.aglib.memory.read(page, size)
             data = bytes(data)
-        except gdb.MemoryError:
+        except pwndbg.dbg_mod.Error:
             debug(DEBUG_MEM_MAP, "Could not map page %#x during emulation! [exception]", page)
             return False
 
@@ -725,16 +733,14 @@ class Emulator:
         debug(DEBUG_MEM_READ, "uc.mem_read(*%r, **%r)", (a, kw))
         return self.uc.mem_read(*a, **kw)
 
-    def until_jump(self, pc=None):
+    def until_jump(self, pc: int = None):
         """
         Emulates instructions starting at the specified address until the
         program counter is set to an address which does not linearly follow
         the previously-emulated instruction.
 
         Arguments:
-            pc(int): Address to start at.  If `None`, uses the current instruction.
-            types(list,set): List of instruction groups to stop at.
-                By default, it stops at all jumps, calls, and returns.
+            pc: Address to start at.  If `None`, uses the current instruction.
 
         Return:
             Returns a tuple containing the address of the jump instruction,
@@ -786,7 +792,7 @@ class Emulator:
     def until_call(self, pc=None):
         addr, target = self.until_jump(pc)
 
-        while target and not pwndbg.gdblib.disasm.one_raw(addr).call_like:
+        while target and not pwndbg.aglib.disasm.one_raw(addr).call_like:
             addr, target = self.until_jump(target)
 
         return addr, target
@@ -824,7 +830,7 @@ class Emulator:
 
         pc = pc or self.pc
 
-        insn = pwndbg.gdblib.disasm.one_raw(pc)
+        insn = pwndbg.aglib.disasm.one_raw(pc)
 
         # If we don't know how to disassemble, bail.
         if insn is None:
